@@ -28,15 +28,10 @@ class PlymouthHelper : public QObject
 {
     Q_OBJECT
 
-public:
-
 public Q_SLOTS:
     ActionReply save(const QVariantMap &map);
     ActionReply install(const QVariantMap &args);
     ActionReply uninstall(const QVariantMap &args);
-
-private:
-    
 };
 
 #endif
